==> permission-service-rest-api-10.4.0-1005.817-sources.jar: ai/digital/deploy/permissions/api/rest/v1/impl/PermissionController.scala <==
package ai.digital.deploy.permissions.api.rest.v1.impl

import ai.digital.deploy.permissions.api.rest.dto.converters.RoleConverter._
import ai.digital.deploy.permissions.api.rest.dto.converters.RoleWithGlobalPermissionsConverter._
import ai.digital.deploy.permissions.api.rest.dto.{CheckPermissionRequest, CheckPermissionWithPrincipalsRequest, CheckPermissionWithReferencesAndPrincipalsRequest, CheckPermissionWithReferencesRequest, ReferencedPermissionsDto, RoleFilterDto, RoleWithPermissionsDto}
import ai.digital.deploy.permissions.api.rest.v1.PermissionResource
import ai.digital.deploy.permissions.api.rest.v1.PermissionsPaths.{BASE_PATH, CHECK_PERMISSION_FOR_ROLES_AND_REFERENCE, CHECK_PERMISSION_FOR_ROLES_AND_REFERENCES, CHECK_PERMISSION_FOR_ROLES_REFERENCES_AND_PRINCIPALS, CHECK_PERMISSION_FOR_ROLES_REFERENCE_AND_PRINCIPALS, GET_ALL_PERMISSION_FOR_ROLE, GET_ALL_PERMISSION_FOR_ROLES, GET_ALL_PERMISSION_FOR_ROLES_WITH_FILTER}
import ai.digital.deploy.permissions.exception.RoleNameNotFoundException
import ai.digital.deploy.permissions.service.{GlobalPermissionService, ReferencedPermissionService, RoleService}
import org.springframework.data.domain.{Page, PageImpl, Pageable}
import org.springframework.web.bind.annotation._

import java.util.UUID
import javax.validation.Valid
import scala.jdk.CollectionConverters._

@RestController
@RequestMapping(Array(BASE_PATH))
class PermissionController(roleService: RoleService,
                           referencedPermissionService: ReferencedPermissionService,
                           globalPermissionService: GlobalPermissionService
) extends PermissionResource {
  @GetMapping(Array(GET_ALL_PERMISSION_FOR_ROLE))
  override def read(@PathVariable roleName: String): RoleWithPermissionsDto = {
    val globalPermissions = globalPermissionService.read(roleName).map(_.permissionName)
    val referencedPermissions = referencedPermissionService.read(roleName).groupBy(_.reference)
    val role = roleService.read(roleName).getOrElse(throw RoleNameNotFoundException(roleName))
    val referencedPermissionsDto = referencedPermissions.map { rp =>
      ReferencedPermissionsDto(rp._1, rp._2.map(_.permissionName))
    }.toList
    RoleWithPermissionsDto(role, globalPermissions, referencedPermissionsDto)
  }

  @GetMapping(Array(GET_ALL_PERMISSION_FOR_ROLES))
  override def read(@RequestBody roleNames: List[String]): List[RoleWithPermissionsDto] = {
    val globalPermissions = globalPermissionService.read(roleNames).groupBy(_.role.name)
    val referencedPermissions = referencedPermissionService.read(roleNames).groupBy(_.role.name)
    val roles = roleService.read(roleNames)
    roles.map { role =>
      val referencedPermissionsForRole = referencedPermissions.getOrElse(role.name, List.empty).groupBy(_.reference)
      val referencedPermissionsDto = referencedPermissionsForRole.map { rp =>
        ReferencedPermissionsDto(rp._1, rp._2.map(_.permissionName))
      }.toList
      RoleWithPermissionsDto(role, globalPermissions.getOrElse(role.name, List.empty), referencedPermissionsDto)
    }
  }

  @GetMapping(Array(GET_ALL_PERMISSION_FOR_ROLES_WITH_FILTER))
  override def read(@RequestBody names: List[String], pageable: Pageable): Page[RoleWithPermissionsDto] = {
    val roles = roleService.read(names, pageable)
    val roleNames = roles.asScala.toList.map(_.name)
    val globalPermissions = globalPermissionService.read(roleNames).groupBy(_.role.name)
    val referencedPermissions = referencedPermissionService.read(roleNames).groupBy(_.role.name)
    val dtos = roles.asScala.toList.map { role =>
      val referencedPermissionsForRole = referencedPermissions.getOrElse(role.name, List.empty).groupBy(_.reference)
      val referencedPermissionsDto = referencedPermissionsForRole.map { rp =>
        ReferencedPermissionsDto(rp._1, rp._2.map(_.permissionName))
      }.toList
      RoleWithPermissionsDto(role, globalPermissions.getOrElse(role.name, List.empty), referencedPermissionsDto)
    }
    new PageImpl[RoleWithPermissionsDto](dtos.asJava, pageable, roles.getTotalElements)
  }

  @GetMapping(Array(CHECK_PERMISSION_FOR_ROLES_AND_REFERENCE))
  override def checkPermission(@Valid @RequestBody checkPermissionRequest: CheckPermissionRequest): Boolean =
    checkPermissionRequest.referenceMaybe
      .map { referenceId =>
        referencedPermissionService.checkPermission(referenceId,
                                                    checkPermissionRequest.permissions,
                                                    checkPermissionRequest.allRoles
        )
      }
      .getOrElse(globalPermissionService.checkPermission(checkPermissionRequest.permissions, checkPermissionRequest.allRoles))

  @GetMapping(Array(CHECK_PERMISSION_FOR_ROLES_REFERENCE_AND_PRINCIPALS))
  override def checkPermission(
    @Valid @RequestBody checkPermissionRequest: CheckPermissionWithPrincipalsRequest
  ): Boolean =
    checkPermissionRequest.referenceMaybe
      .map { referenceId =>
        referencedPermissionService.checkPermission(
          referenceId,
          checkPermissionRequest.permissions,
          checkPermissionRequest.allRoles,
          checkPermissionRequest.principals
        )
      }
      .getOrElse(
        globalPermissionService
          .checkPermission(checkPermissionRequest.permissions, checkPermissionRequest.allRoles, checkPermissionRequest.principals)
      )

  @GetMapping(Array(CHECK_PERMISSION_FOR_ROLES_AND_REFERENCES))
  override def checkPermission(
    @Valid @RequestBody checkPermissionRequest: CheckPermissionWithReferencesRequest
  ): Map[String, Boolean] =
    if (checkPermissionRequest.references.isEmpty)
      Map(
        "global" -> globalPermissionService.checkPermission(checkPermissionRequest.permissions, checkPermissionRequest.allRoles)
      )
    else
      checkPermissionRequest.references
        .map(reference =>
          reference.toString -> referencedPermissionService
            .checkPermission(reference, checkPermissionRequest.permissions, checkPermissionRequest.allRoles)
        ).toMap

  @GetMapping(Array(CHECK_PERMISSION_FOR_ROLES_REFERENCES_AND_PRINCIPALS))
  override def checkPermission(
    @Valid @RequestBody checkPermissionRequest: CheckPermissionWithReferencesAndPrincipalsRequest
  ): Map[String, Boolean] =
    if (checkPermissionRequest.references.isEmpty)
      Map(
        "global" -> globalPermissionService.checkPermission(checkPermissionRequest.permissions,
                                                            checkPermissionRequest.allRoles,
                                                            checkPermissionRequest.principals
        )
      )
    else
      checkPermissionRequest.references
        .map(reference =>
          reference.toString -> referencedPermissionService.checkPermission(reference,
                                                                            checkPermissionRequest.permissions,
                                                                            checkPermissionRequest.allRoles,
                                                                            checkPermissionRequest.principals
          )
        ).toMap
}

==> permission-service-rest-api-10.4.0-1013.1441-sources.jar: ai/digital/deploy/permissions/api/rest/v1/impl/PermissionController.scala <==
package ai.digital.deploy.permissions.api.rest.v1.impl

import ai.digital.deploy.permissions.api.rest.dto.converters.RoleConverter._
import ai.digital.deploy.permissions.api.rest.dto.converters.RoleWithGlobalPermissionsConverter._
import ai.digital.deploy.permissions.api.rest.dto.{CheckPermissionRequest, CheckPermissionWithPrincipalsRequest, CheckPermissionWithReferencesAndPrincipalsRequest, CheckPermissionWithReferencesRequest, ReferencedPermissionsDto, RoleFilterDto, RoleWithPermissionsDto}
import ai.digital.deploy.permissions.api.rest.v1.PermissionsPaths.{BASE_PATH, CHECK_PERMISSION_FOR_ROLES_AND_REFERENCE, CHECK_PERMISSION_FOR_ROLES_AND_REFERENCES, CHECK_PERMISSION_FOR_ROLES_REFERENCES_AND_PRINCIPALS, CHECK_PERMISSION_FOR_ROLES_REFERENCE_AND_PRINCIPALS, GET_ALL_PERMISSION_FOR_ROLE, GET_ALL_PERMISSION_FOR_ROLES, GET_ALL_PERMISSION_FOR_ROLES_WITH_FILTER}
import ai.digital.deploy.permissions.exception.RoleNameNotFoundException
import ai.digital.deploy.permissions.service.{GlobalPermissionService, ReferencedPermissionService, RoleService}
import org.springframework.data.domain.{Page, PageImpl, Pageable}
import org.springframework.web.bind.annotation._

import java.util.UUID
import javax.validation.Valid
import scala.jdk.CollectionConverters._

@RestController
@RequestMapping(Array(BASE_PATH))
class PermissionController(roleService: RoleService,
                           referencedPermissionService: ReferencedPermissionService,
                           globalPermissionService: GlobalPermissionService
) {
  @GetMapping(Array(GET_ALL_PERMISSION_FOR_ROLE))
  def read(@PathVariable roleName: String): RoleWithPermissionsDto = {
    val globalPermissions = globalPermissionService.read(roleName).map(_.permissionName)
    val referencedPermissions = referencedPermissionService.read(roleName).groupBy(_.reference)
    val role = roleService.read(roleName).getOrElse(throw RoleNameNotFoundException(roleName))
    val referencedPermissionsDto = referencedPermissions.map { rp =>
      ReferencedPermissionsDto(rp._1, rp._2.map(_.permissionName))
    }.toList
    RoleWithPermissionsDto(role, globalPermissions, referencedPermissionsDto)
  }

  @GetMapping(Array(GET_ALL_PERMISSION_FOR_ROLES))
  def read(@RequestBody roleNames: List[String]): List[RoleWithPermissionsDto] = {
    val globalPermissions = globalPermissionService.read(roleNames).groupBy(_.role.name)
    val referencedPermissions = referencedPermissionService.read(roleNames).groupBy(_.role.name)
    val roles = roleService.read(roleNames)
    roles.map { role =>
      val referencedPermissionsForRole = referencedPermissions.getOrElse(role.name, List.empty).groupBy(_.reference)
      val referencedPermissionsDto = referencedPermissionsForRole.map { rp =>
        ReferencedPermissionsDto(rp._1, rp._2.map(_.permissionName))
      }.toList
      RoleWithPermissionsDto(role, globalPermissions.getOrElse(role.name, List.empty), referencedPermissionsDto)
    }
  }

  @GetMapping(Array(GET_ALL_PERMISSION_FOR_ROLES_WITH_FILTER))
  def read(@RequestBody names: List[String], pageable: Pageable): Page[RoleWithPermissionsDto] = {
    val roles = roleService.read(names, pageable)
    val roleNames = roles.asScala.toList.map(_.name)
    val globalPermissions = globalPermissionService.read(roleNames).groupBy(_.role.name)
    val referencedPermissions = referencedPermissionService.read(roleNames).groupBy(_.role.name)
    val dtos = roles.asScala.toList.map { role =>
      val referencedPermissionsForRole = referencedPermissions.getOrElse(role.name, List.empty).groupBy(_.reference)
      val referencedPermissionsDto = referencedPermissionsForRole.map { rp =>
        ReferencedPermissionsDto(rp._1, rp._2.map(_.permissionName))
      }.toList
      RoleWithPermissionsDto(role, globalPermissions.getOrElse(role.name, List.empty), referencedPermissionsDto)
    }
    new PageImpl[RoleWithPermissionsDto](dtos.asJava, pageable, roles.getTotalElements)
  }

  @GetMapping(Array(CHECK_PERMISSION_FOR_ROLES_AND_REFERENCE))
  def checkPermission(@Valid @RequestBody checkPermissionRequest: CheckPermissionRequest): Boolean =
    checkPermissionRequest.referenceMaybe
      .map { referenceId =>
        referencedPermissionService.checkPermission(referenceId,
                                                    checkPermissionRequest.permissions,
                                                    checkPermissionRequest.allRoles
        )
      }
      .getOrElse(globalPermissionService.checkPermission(checkPermissionRequest.permissions, checkPermissionRequest.allRoles))

  @GetMapping(Array(CHECK_PERMISSION_FOR_ROLES_REFERENCE_AND_PRINCIPALS))
  def checkPermission(
    @Valid @RequestBody checkPermissionRequest: CheckPermissionWithPrincipalsRequest
  ): Boolean =
    checkPermissionRequest.referenceMaybe
      .map { referenceId =>
        referencedPermissionService.checkPermission(
          referenceId,
          checkPermissionRequest.permissions,
          checkPermissionRequest.allRoles,
          checkPermissionRequest.principals
        )
      }
      .getOrElse(
        globalPermissionService
          .checkPermission(checkPermissionRequest.permissions, checkPermissionRequest.allRoles, checkPermissionRequest.principals)
      )

  @GetMapping(Array(CHECK_PERMISSION_FOR_ROLES_AND_REFERENCES))
  def checkPermission(
    @Valid @RequestBody checkPermissionRequest: CheckPermissionWithReferencesRequest
  ): Map[String, Boolean] =
    if (checkPermissionRequest.references.isEmpty)
      Map(
        "global" -> globalPermissionService.checkPermission(checkPermissionRequest.permissions, checkPermissionRequest.allRoles)
      )
    else
      checkPermissionRequest.references
        .map(reference =>
          reference.toString -> referencedPermissionService
            .checkPermission(reference, checkPermissionRequest.permissions, checkPermissionRequest.allRoles)
        ).toMap

  @GetMapping(Array(CHECK_PERMISSION_FOR_ROLES_REFERENCES_AND_PRINCIPALS))
  def checkPermission(
    @Valid @RequestBody checkPermissionRequest: CheckPermissionWithReferencesAndPrincipalsRequest
  ): Map[String, Boolean] =
    if (checkPermissionRequest.references.isEmpty)
      Map(
        "global" -> globalPermissionService.checkPermission(checkPermissionRequest.permissions,
                                                            checkPermissionRequest.allRoles,
                                                            checkPermissionRequest.principals
        )
      )
    else
      checkPermissionRequest.references
        .map(reference =>
          reference.toString -> referencedPermissionService.checkPermission(reference,
                                                                            checkPermissionRequest.permissions,
                                                                            checkPermissionRequest.allRoles,
                                                                            checkPermissionRequest.principals
          )
        ).toMap
}
